# Starlette Session

<p align="center">

<a href="https://github.com/auredentan/starlette-session/actions?query=workflow%3ATest" target="_blank">
    <img src="https://github.com/auredentan/starlette-session/workflows/Test/badge.svg?branch=master" alt="Test">
</a>

<a href="https://pypi.org/project/starlette-session" target="_blank">
    <img src="https://img.shields.io/pypi/v/starlette-session?color=%2334D058&label=pypi%20package" alt="Package version">
</a>

<a href="https://codecov.io/gh/auredentan/starlette-session">
  <img src="https://codecov.io/gh/auredentan/starlette-session/branch/master/graph/badge.svg" />
</a>

</p>

---

Starlette session middleware